@@ -584,7 +584,7 @@ def caculate_nornalization_dp(reference, ndp_r_spec_list, bin_spectra, ndp_bin_s
     return result
 
 
-def encode_spectra(prj, input_file, reference_spectra,  **kw):
+def encode_spectra(prj, input, reference_spectra,  **kw):
     """
     Encode spectra
     :param prj: ProteomeXchange project/dataset accession
@@ -593,7 +593,7 @@ def encode_spectra(prj, input_file, reference_spectra,  **kw):
     :param kw: miss_record, ids_usi_save_file, encoded_spectra_save_file
     :return: ids_usi data, encoded_spectra data
     """
-    dirname, filename = os.path.split(os.path.abspath(input_file))
+    dirname, filename = os.path.split(os.path.abspath(input))
     if kw.keys().__contains__("miss_record"):
         miss_record = kw["miss_record"]
     else:
@@ -609,29 +609,29 @@ def encode_spectra(prj, input_file, reference_spectra,  **kw):
     else:
         encoded_spectra_save_file = dirname + "/" + filename.strip((filename.split(".")[-1])).strip(".") + "_encoded.npy"
 
-    if str(input_file).endswith(".mgf"):
+    if str(input).endswith(".mgf"):
         spectra_num = more_itertools.ilen(mgf_read(input, convert_arrays=1))
 
         mgf_encoder = EncodeDataset(spectra_num)
-        ids_usi_df, vstack_data = mgf_encoder.transform_mgf(prj, input_file, reference_spectra, miss_record)
+        ids_usi_df, vstack_data = mgf_encoder.transform_mgf(prj, input, reference_spectra, miss_record)
 
         pd.DataFrame(ids_usi_df).to_csv(ids_usi_save_file, header=True, index=None)
         np.save(encoded_spectra_save_file, vstack_data)
 
         return ids_usi_df, vstack_data
 
-    elif str(input_file).endswith(".mzML"):
+    elif str(input).endswith(".mzML"):
 
-        spectra_num = more_itertools.ilen(mzml_read(input_file))
+        spectra_num = more_itertools.ilen(mzml_read(input))
         mzml_encoder = EncodeDataset(spectra_num)
-        ids_usi_df, vstack_data = mzml_encoder.transform_mzml(prj, input_file, reference_spectra, miss_record)
+        ids_usi_df, vstack_data = mzml_encoder.transform_mzml(prj, input, reference_spectra, miss_record)
 
         pd.DataFrame(ids_usi_df).to_csv(ids_usi_save_file, header=True, index=None)
         np.save(encoded_spectra_save_file, vstack_data)
 
         return ids_usi_df, vstack_data
     else:
-        with open(input_file) as fh:
+        with open(input) as fh:
             spectra_json_file = [json.loads(line) for line in fh if line]
         spectra_num = len(spectra_json_file)
         json_encoder = EncodeDataset(spectra_num)
